==> ann-0.2.tar.gz: ann-0.2/include/ann_parser_ws.h <==
/***************************************************************************
                          ann_parser_ws.h  -  description
                             -------------------
    begin                : pon kwi 21 2003
    copyright            : (C) 2003 by Bartosz Lis
    email                : bartoszl@ics.p.lodz.pl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef __ANN_PARSER_WS_H
#define __ANN_PARSER_WS_H

#include <iostream>

#include <ann_tc.h>

namespace ANN
{

  //                 //
 // class Parser_ws //
//                 //

  class Parser_ws
  {
  protected:

    TC   *in;
    TC   *des_out;
    bool  is_out;

    virtual bool  add_str(const char *str, size_t len);
    virtual void  add_val(double x);
    virtual void  add_line();
    virtual bool  internal_parse(std::istream &is);

  public:
    Parser_ws();
    virtual ~Parser_ws();

    TC           &input() { return *in; }
    const TC     &input() const { return *in; }
    TC           &des_output() { return *des_out; }
    const TC     &des_output() const { return *des_out; }
    void          clear(size_t pos=0);
    bool          parse(std::istream &is);
    bool          operator() (std::istream &is) { return parse(is); }
  };
  
} // namespace ANN

#endif /* __ANN_PARSER_WS_H */

==> ann-0.3.tar.gz: ann-0.3/include/ann_parser_ws.h <==
/***************************************************************************
                          ann_parser_ws.h  -  description
                             -------------------
    begin                : pon kwi 21 2003
    copyright            : (C) 2003 by Bartosz Lis
    email                : bartoszl@ics.p.lodz.pl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef __ANN_PARSER_WS_H
#define __ANN_PARSER_WS_H

#include <iostream>

#include <ann_tc.h>

namespace ANN
{

  //                 //
 // class Parser_ws //
//                 //

  class Parser_ws
  {
  protected:

    TC      *in;
    TC      *des_out;
    TC::Pos  pos_where;
    TC::Pos  pos_loc;
    Loc      where;
    Loc      loc;
    bool     is_out;
    bool     was_val;

    virtual bool  add_str(const char *str, size_t len);
    virtual void  add_val(double x);
    virtual void  add_line();
    virtual bool  des_out_patt();
    virtual bool  internal_parse(std::istream &is);

  public:
    Parser_ws();
    virtual ~Parser_ws();

    TC           &input() { return *in; }
    const TC     &input() const { return *in; }
    TC           &des_output() { return *des_out; }
    const TC     &des_output() const { return *des_out; }
    void          clear(size_t pos=0);
    bool          parse(std::istream &is);
    bool          operator() (std::istream &is) { return parse(is); }
  };
  
} // namespace ANN

#endif /* __ANN_PARSER_WS_H */
